# This file is auto-generated by hatch-gradle-version. Do not edit.

GRADLE_VERSION = "0.1.5.1.1.20.1"
FULL_VERSION = "0.1.5.1.1.20.1.1.2"

CURSEFORGE_ID = "1387372"
JETBRAINS_ANNOTATIONS_VERSION = "23.0.0"
KOTLIN_STDLIB_DEFAULT_DEPENDENCY = "false"
MAVEN_GROUP = "io.github.real_septicake.hexthings"
MINECRAFT_VERSION = "1.20.1"
MOD_ID = "hexthings"
MOD_VERSION = "0.1.5.1"
MODRINTH_ID = "uRBPvIjK"
ORG_GRADLE_JVMARGS = "-Xmx4096M"
